
{ config, pkgs, lib, ... }:
{
  # Define a user account. Don't forget to set a password with ‘passwd’.
  users.users.leonv = {
    isNormalUser = true;
    description = "Leon Vatthauer";
    extraGroups = [ "networkmanager" "wheel" ];
    initialPassword = "leonv";
  };

  networking.hostName = "iso"; # Define your hostname.
  # Enable networking
  networking.networkmanager = {
    enable = true;
  };

  # Set your time zone.
  time.timeZone = "Europe/Berlin";

  i18n.supportedLocales = [
    "en_US.UTF-8/UTF-8"
    "de_DE.UTF-8/UTF-8"
  ];

  # Select internationalisation properties.
  i18n.defaultLocale = "en_US.UTF-8";

  i18n.extraLocaleSettings = {
    LANG = "en_US.UTF-8";
    LC_ALL = "en_US.UTF-8";
    LANGUAGE = "en_US.UTF-8";
    LC_ADDRESS = "de_DE.UTF-8";
    LC_IDENTIFICATION = "de_DE.UTF-8";
    LC_MEASUREMENT = "de_DE.UTF-8";
    LC_MONETARY = "de_DE.UTF-8";
    LC_NAME = "de_DE.UTF-8";
    LC_NUMERIC = "de_DE.UTF-8";
    LC_PAPER = "de_DE.UTF-8";
    LC_TELEPHONE = "de_DE.UTF-8";
    LC_TIME = "de_DE.UTF-8";
  };

  # Enable sound with pipewire.
  sound.enable = true;
  hardware.pulseaudio.enable = false;
  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
  };

  # Allow unfree packages
  nixpkgs.config.allowUnfree = true;

  # List packages installed in system profile.
  environment.systemPackages = with pkgs; [
    # some standards for convenience
    vim
    parted
    gparted
    git
  ];

  system.stateVersion = "24.05"; # Did you read the comment?

  # source zsh
  programs.zsh.enable = true;
  users.defaultUserShell = pkgs.zsh;

  # Binary Cache for Haskell.nix
  nix.settings.trusted-public-keys = [
    "hydra.iohk.io:f/Ea+s+dFdN+3Y/G+FDgSq+a5NEWhJGzdjvKNGv0/EQ="
  ];
  nix.settings.substituters = [
    "https://aseipp-nix-cache.global.ssl.fastly.net" 
    "https://cache.iog.io"
  ];

  # flakes
  nix.settings.experimental-features = [ "nix-command" "flakes" ];
}
